# -*- coding: utf-8 -*-
# @author: leesoar

"""postcard"""

from postcard.imap import *
from postcard.pop3 import *
from postcard.smtp import *


__version__ = "0.3.1"
